==> haskell-yesod-test-1.6.16-128-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-test.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod-test
version:              1.6.16
visibility:           public
id:                   yesod-test-1.6.16-3lJDk62FQrpID5IgFYORb9
key:                  yesod-test-1.6.16-3lJDk62FQrpID5IgFYORb9
license:              MIT
maintainer:           Michael Snoyman, Greg Weber, Nubis <nubis@woobiz.com.ar>
author:               Nubis <nubis@woobiz.com.ar>
stability:            Experimental
homepage:             http://www.yesodweb.com
synopsis:             integration testing for WAI/Yesod Applications
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-test>

category:             Web, Yesod, Testing
abi:                  540e0ab582c5d630e2feeb6f4a0b8d65
exposed:              True
exposed-modules:
    Yesod.Test Yesod.Test.CssQuery Yesod.Test.Internal
    Yesod.Test.Internal.SIO Yesod.Test.TransversingCSS

import-dirs:          /usr/lib/ghc-9.4.8/site-local/yesod-test-1.6.16
library-dirs:         /usr/lib/ghc-9.4.8/site-local/yesod-test-1.6.16
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/yesod-test-1.6.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-test
hs-libraries:         HSyesod-test-1.6.16-3lJDk62FQrpID5IgFYORb9
depends:
    HUnit-1.6.2.0-DUvlqmsw2Kp6tCDRl9WtXA
    aeson-2.1.2.1-7NKMY9av0haL3nHVKphSJj
    attoparsec-0.14.4-8RYxJQa7MEjKmC3I11Us4k base-4.17.2.1
    blaze-builder-0.4.2.3-1WUo1omsOYUH2PSkelI6MS
    blaze-html-0.9.2.0-4j6jevlp0QUEusbPG23DSX
    blaze-markup-0.8.3.0-E3xIpXEfOxQ70jxLTxkTyw bytestring-0.11.5.3
    case-insensitive-1.2.1.0-BBd0FN3VG9pHwba5nfbZ8v
    conduit-1.3.6.1-86fl8mgs0PcICSp2A4xyva containers-0.6.7
    cookie-0.4.6-4KcZJbma3z5GIFijXOzknm
    hspec-core-2.10.9-Fep4H79ORNbRiVNEYp9q8
    html-conduit-1.3.2.2-7aFrCywIlZg2b0VjzQC8WS
    http-types-0.12.4-1DZFzfvJVK9AHfgKU8FkY3
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt mtl-2.2.2
    network-3.1.4.0-7d91dIi13MzEkgRQe6YDcO
    pretty-show-1.10-Il8DKxKkDEW3pjtvdJ1ynD text-2.0.2 time-1.12.2
    transformers-0.5.6.2 wai-3.2.4-LaZv3Kj0Ed9gV12y2mMCG
    wai-extra-3.1.16-LREM6CQuOwCLYxhEeUHpj
    xml-conduit-1.9.1.4-6ibtXNKQV6nGMpLg2qNsD5
    xml-types-0.3.8-IpGyuvvNOu2AH1SOobl25
    yesod-core-1.6.26.0-2YUT5dn4HXTEvKAeT5KKAw

haddock-interfaces:   /usr/share/doc/haskell-yesod-test/html/yesod-test.haddock
haddock-html:         /usr/share/doc/haskell-yesod-test/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-test-1.6.16-129-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-test.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod-test
version:              1.6.16
visibility:           public
id:                   yesod-test-1.6.16-4s2pmyaIgSwEZdOVsR4mi2
key:                  yesod-test-1.6.16-4s2pmyaIgSwEZdOVsR4mi2
license:              MIT
maintainer:           Michael Snoyman, Greg Weber, Nubis <nubis@woobiz.com.ar>
author:               Nubis <nubis@woobiz.com.ar>
stability:            Experimental
homepage:             http://www.yesodweb.com
synopsis:             integration testing for WAI/Yesod Applications
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-test>

category:             Web, Yesod, Testing
abi:                  13ab6c28888fe129fac5ca2e1cc22855
exposed:              True
exposed-modules:
    Yesod.Test Yesod.Test.CssQuery Yesod.Test.Internal
    Yesod.Test.Internal.SIO Yesod.Test.TransversingCSS

import-dirs:          /usr/lib/ghc-9.4.8/site-local/yesod-test-1.6.16
library-dirs:         /usr/lib/ghc-9.4.8/site-local/yesod-test-1.6.16
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/yesod-test-1.6.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-test
hs-libraries:         HSyesod-test-1.6.16-4s2pmyaIgSwEZdOVsR4mi2
depends:
    HUnit-1.6.2.0-DUvlqmsw2Kp6tCDRl9WtXA
    aeson-2.1.2.1-7NKMY9av0haL3nHVKphSJj
    attoparsec-0.14.4-8RYxJQa7MEjKmC3I11Us4k base-4.17.2.1
    blaze-builder-0.4.2.3-1WUo1omsOYUH2PSkelI6MS
    blaze-html-0.9.2.0-4j6jevlp0QUEusbPG23DSX
    blaze-markup-0.8.3.0-E3xIpXEfOxQ70jxLTxkTyw bytestring-0.11.5.3
    case-insensitive-1.2.1.0-BBd0FN3VG9pHwba5nfbZ8v
    conduit-1.3.6.1-86fl8mgs0PcICSp2A4xyva containers-0.6.7
    cookie-0.4.6-4KcZJbma3z5GIFijXOzknm
    hspec-core-2.10.9-Fep4H79ORNbRiVNEYp9q8
    html-conduit-1.3.2.2-7aFrCywIlZg2b0VjzQC8WS
    http-types-0.12.4-1DZFzfvJVK9AHfgKU8FkY3
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt mtl-2.2.2
    network-3.1.4.0-7d91dIi13MzEkgRQe6YDcO
    pretty-show-1.10-Il8DKxKkDEW3pjtvdJ1ynD text-2.0.2 time-1.12.2
    transformers-0.5.6.2 wai-3.2.4-LaZv3Kj0Ed9gV12y2mMCG
    wai-extra-3.1.16-I7ARULvVS8bK906k5FQwhX
    xml-conduit-1.9.1.4-6ibtXNKQV6nGMpLg2qNsD5
    xml-types-0.3.8-IpGyuvvNOu2AH1SOobl25
    yesod-core-1.6.26.0-1gQhTetVhel7YKGUqnl4Yf

haddock-interfaces:   /usr/share/doc/haskell-yesod-test/html/yesod-test.haddock
haddock-html:         /usr/share/doc/haskell-yesod-test/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
